@@ -74,7 +74,7 @@ sub paper_size {
   my ($paper_name) = @_;
   chomp($paper_name = paper([])) unless defined($paper_name);
   my $dimensions = paper(["-s", "$paper_name"], 1) or return;
-  $dimensions =~ /^(\S+) (\S+)/;
+  $dimensions =~ /^([.0-9]+) ([.0-9]+)$/;
   my $old_locale = setlocale(LC_ALL);
   setlocale(LC_ALL, "");
   my ($w, $w_unparsed) = strtod($1);
